///////////////////////////////////////////////////////////////////////////////
// DC_CombineImages.js
///////////////////////////////////////////////////////////////////////////////
//
// DC_CombineImages: Version 0.61
//
// A script to combine multiple grayscale images to form a single color image
// with user-defined colors
//
// Copyright (c) 2018-2022 Dean Carr
//
///////////////////////////////////////////////////////////////////////////////

#feature-id    DC_Scripts >  CombineImages

#feature-info  A script to combine multiple grayscale images to form a singe color image with user-defined colors

//------------------------------------------------------------------------------

#include "System/DC_CombineImages_the_app.js"
#include "System/DC_CombineImages_dialog.js"

///////////////////////////////////////////////////////////////////////////////

// This script maintains three primary objects: 'g_control_data', 'theApp',
// and 'dialog'.

// g_control_data, based on GlobalControlData, records basic 'wrapper'
// information such as 'script_title', 'script_version', and
// 'root_folder' (where this top-level' script resides).

// 'dialog', based on 'AppDialog()', provides the user interface
// and controls all interactions with 'theApp'.

// 'theApp', based on 'TheApplication()', defines data and methods
// directly related to the operation of the script. 'theApp'has no'knowledge' of
// 'dialog', except for a local reference to the dialog's status_bar.

///////////////////////////////////////////////////////////////////////////////
// Global Variables
///////////////////////////////////////////////////////////////////////////////

function GlobalControlData()
{

    this.script_title    = "Combine Images"

    this.script_version  = "0.61";

    this.script_file_path = #__FILE__;

    this.root_folder =   File.extractDrive(this.script_file_path)
                       + File.extractDirectory(this.script_file_path);

}

//------------------------------------------------------------------------------

// Instantiate GlobalControlData()
let g_control_data = new GlobalControlData();

///////////////////////////////////////////////////////////////////////////////
// Script entry point
///////////////////////////////////////////////////////////////////////////////

function main()
{

    let theApp = new TheApplication(g_control_data.root_folder);

    theApp.initialize() ;

    console.writeln( "<end><cbr/><br/>" );
    console.writeln( "<end><cbr/><br/><b>","======================================================================", "</b>" );
    console.writeln( "<end><cbr/><br/><b>","BEGIN SCRIPT", "</b>" );
    console.writeln( "<end><cbr/><br/><b>","Control Script: "
                                           + g_control_data.script_title + " "
                                           + g_control_data.script_version, "</b>" );
    console.writeln( "<end><cbr/><br/><b>","Helper Script: "
                                           + g_helper_data.script_title + " "
                                           + g_helper_data.script_version, "</b>" );
    console.writeln( "<end><cbr/><br/><b>","======================================================================", "</b>" );

    // Code to save all icons used in the script
/*
    let icons_folder = g_control_data.root_folder + "/System/Icons" ;

    if (!File.directoryExists(icons_folder))
    {
        File.createDirectory(icons_folder);
    }

    let icon_array = [
                         ":/auto-hide/floating.png",
                         ":/browser/select-file-1.png",
                         ":/icons/color-wheel.png",
                         ":/icons/control-button.png",
                         ":/icons/copy.png",
                         ":/icons/documents-import.png",
                         ":/icons/document-save.png",
                         ":/icons/execute.png",
                         ":/icons/item.png",
                         ":/icons/item-import.png",
                         ":/icons/item-export.png",
                         ":/icons/ok.png",
                         ":/icons/paste.png",
                         ":/icons/refresh.png",
                         ":/icons/picture-export.png",
                         ":/icons/power.png",
                         ":/icons/reload.png",
                         ":/icons/settings.png",
                         ":/image-container/image-container-icon.png",
                         ":/messages/check.png",
                         ":/process-interface/real-time-active.png",
                         ":/toolbar/image-display-rgb.png",
                         ":/toolbar/image-display-saturation.png",
                         ":/toolbar/process-favorites-save.png"
                     ];

    let num_icons = icon_array.length;

    for (let i = 0; i < num_icons; i++ )
    {
        let iconResource = icon_array[i];
        let icon = new Bitmap( iconResource );
        let icon_name = File.extractNameAndExtension(icon_array[i]);

        icon.save(icons_folder + "/" + icon_name);
    };

*/

    // Hide console while dialog is active.
    // console.hide();

    // Open images stored in the 'Input Images' folder, for access on the PixInsight desktop
    theApp.autoOpenInputImages();

    // It is now up to the Dialog to populate dialog rows with images

    let dialog = new AppDialog(theApp, g_control_data.root_folder);

    console.abortEnabled = true;

    dialog.execute();

    console.show();

    console.writeln( "<end><cbr/><br/>" );
    console.writeln( "<end><cbr/><br/><b>","======================================================================", "</b>" );
    console.writeln( "<end><cbr/><br/><b>","END SCRIPT", "</b>" );
    console.writeln( "<end><cbr/><br/><b>","Control Script: "
                                           + g_control_data.script_title + " "
                                           + g_control_data.script_version, "</b>" );
    console.writeln( "<end><cbr/><br/><b>","Helper Script: "
                                           + g_helper_data.script_title + " "
                                           + g_helper_data.script_version, "</b>" );
    console.writeln( "<end><cbr/><br/><b>","======================================================================", "</b>" );

    theApp.saveDiagnostics();

};

//------------------------------------------------------------------------------

main();

///////////////////////////////////////////////////////////////////////////////
// EOF DC_CombineImages.js
///////////////////////////////////////////////////////////////////////////////
