///////////////////////////////////////////////////////////////////////////////
// DC_CombineImages_default_system_palettes.js
///////////////////////////////////////////////////////////////////////////////
//
// DC_CombineImages: Version 0.61
//
// A script to combine multiple grayscale images to form a single color image
// with user-defined colors
//
// Copyright (c) 2018-2022 Dean Carr
//
///////////////////////////////////////////////////////////////////////////////

#ifndef DC_CombineImages_default_system_palettes_js
#define DC_CombineImages_default_system_palettes_js

//------------------------------------------------------------------------------

function Palettes()
{

    this.__base__ = Object,
    this.__base__(),

    // Initial solution was to use map() of map(), but objects easier for JSON conversions

    ///////////////////////////////////////////////////////////////////

    this.filter_palettes =
    {

        "NONE"    : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "JWST"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,  255, 255 ]
                    },

    ////////////////////////////////////////////////////////////////////////////
    // RGB Broadband Filters - Palette Settings
    ////////////////////////////////////////////////////////////////////////////

        "LUM"     : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "JWST"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,  255, 255 ]
                    },

        "RED"     : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,    0,   0 ],
                        "CFHT"    : [ 100,  255,    0,   0 ],
                        "SDSS"    : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  255,    0,   0 ],
                        "NATURAL" : [ 100,  255,    0,   0 ]
                    },

        "GREEN"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,    0,  255,   0 ],
                        "CFHT"    : [ 100,    0,  255,   0 ],
                        "SDSS"    : [ 100,    0,  255,   0 ],
                        "JWST"    : [ 100,    0,  255,   0 ],
                        "NATURAL" : [ 100,    0,  255,   0 ]
                    },

        "BLUE"    : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"      : [ 100,   0,    0, 255 ],
                        "CFHT"     : [ 100,   0,    0, 255 ],
                        "SDSS"     : [ 100,   0,    0, 255 ],
                        "JWST"     : [ 100,   0,    0, 255 ],
                        "NATURAL"  : [ 100,   0,    0, 255 ]
                    },

    ////////////////////////////////////////////////////////////////////////////
    // 'Traditional' Narrowband Filters - Palette Settings
    ////////////////////////////////////////////////////////////////////////////

        "HA"      : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,    0,  255,   0 ],
                        "CFHT"    : [ 100,    0,  255,   0 ],
                        "SDSS"    : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  255,    0,   0 ],
                        "NATURAL" : [ 100,  255,    0,   0 ]
                    },

        "OIII"    : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,    0,    0, 255 ],
                        "CFHT"    : [ 100,  255,    0,   0 ],
                        "SDSS"    : [ 100,    0,  255, 135 ],
                        "JWST"    : [ 100,    0,  255, 135 ],
                        "NATURAL" : [ 100,    0,  255, 135 ]
                    },

        "SII"     : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,    0,   0 ],
                        "CFHT"    : [ 100,    0,    0, 255 ],
                        "SDSS"    : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  255,    0,   0 ],
                        "NATURAL" : [ 100,  255,    0,   0 ]
                    },

        "HB"      : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,    0,    0,   0 ],
                        "CFHT"    : [ 100,    0,    0,   0 ],
                        "SDSS"    : [ 100,    0,    0, 255 ],
                        "JWST"    : [ 100,    0,    0, 255 ],
                        "NATURAL" : [ 100,    0,    0, 255 ]
                    },


        "IR"      : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  220,   20,  60 ],
                        "CFHT"    : [ 100,  220,   20,  60 ],
                        "SDSS"    : [ 100,  220,   20,  60 ],
                        "JWST"    : [ 100,  220,   20,  60 ],
                        "NATURAL" : [ 100,  220,   20,  60 ]
                    },

    ////////////////////////////////////////////////////////////////////////////
    // SDSS Filters - Palette Settings
    ////////////////////////////////////////////////////////////////////////////

        "I"       : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  220,   20,  60]
                    },

        "SDSS-I"  : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  255,    0,   0 ],
                        "NATURAL" : [ 100,  220,   20,  60 ]
                    },

        "R"       : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,    0,   0 ],
                        "CFHT"    : [ 100,  255,    0,   0 ],
                        "SDSS"    : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  255,    0,   0 ],
                        "NATURAL" : [ 100,  255,    0,   0 ]
                    },

        "SDSS-R"  : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,    0,   0 ],
                        "CFHT"    : [ 100,  255,    0,   0 ],
                        "SDSS"    : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  255,    0,   0 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                    },

        "G"       : {
                        "HST"     : [ 100,    0,  255,   0 ],
                        "CFHT"    : [ 100,    0,  255,   0 ],
                        "SDSS"    : [ 100,    0,  255,   0 ],
                        "JWST"    : [ 100,    0,  255,   0 ],
                        "NATURAL" : [ 100,    0,  255,   0 ]
                    },

        "SDSS-G"  : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,    0,  255,   0 ],
                        "CFHT"    : [ 100,    0,  255,   0 ],
                        "SDSS"    : [ 100,    0,  255,   0 ],
                        "JWST"    : [ 100,    0,  255,   0 ],
                        "NATURAL" : [ 100,    0,  255,   0 ]
                    },

        "U"       : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  238,  130, 238 ],
                        "JWST"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  238,  130, 238 ]
                    },

        "SDSS-U"  : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  238,  130, 238 ],
                        "JWST"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  238,  130, 238 ]
                    },

        "Z"       : {
                       "NONE"    : [ 100,  255,  255, 255 ],
                       "HST"     : [ 100,  255,  255, 255 ],
                       "CFHT"    : [ 100,  255,  255, 255 ],
                       "SDSS"    : [ 100,  128,    0,   0 ],
                       "JWST"    : [ 100,  255,  255, 255 ],
                       "NATURAL" : [ 100,  128,    0,   0 ]
                    },

        "SDSS-Z"  : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  128,    0,   0 ],
                        "JWST"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  128,    0,   0 ]
                    },


    ////////////////////////////////////////////////////////////////////////////
    // JWST NIRI Filters - Palette Settings
    ////////////////////////////////////////////////////////////////////////////

    // Short Wavelengths

        "F070W"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  167,  130, 184 ]
                    },

        "F090W"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  178,  131, 199 ]
                    },

        "F115W"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  137,  130, 210 ]
                    },

        "F140M"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                       "JWST"    : [ 100,  127,  127, 237 ]
                    },

        "F150W"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  135,  151, 238 ]
                    },

        "F150W2"  : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  150,  193, 238 ]
                    },

        "F162M"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  147,  187, 238 ]
                    },

        "F164N"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  145,  193, 239 ]
                    },

        "F182M"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  154,  202, 238 ]
                    },

        "F187N"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  157,  204, 234 ]
                    },

        "F200W"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  156,  207, 224 ]
                    },

        "F210M"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  157,  211, 213 ]
                    },

        "F212N"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  159,  210, 213 ]
                    },

        // Long Wavelengths

        "F250M"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  155,  203, 141 ]
                    },

        "F277W"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  162,  220, 133 ]
                    },

        "F300M"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  170,  238, 135 ]
                    },

        "F322W2"  : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  195,  252, 135 ]
                    },

        "F323N"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,  255, 255 ],
                        "JWST"    : [ 100,  184,  254, 138 ]
                    },

        "F335M"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  213,  253, 138 ]
                    },

        "F356W"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  242,  249, 137 ]
                    },

        "F360M"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  244,  246, 136 ]
                    },

        "F405N"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  245,  210, 126 ]
                    },

        "F410M"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  242,  209, 132 ]
                    },

        "F430M"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  231,  145, 128 ]
                    },

        "F444W"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,  255, 255 ],
                        "JWST"    : [ 100,  223,  134, 128 ]
                    },

        "F460M"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  212,  133, 128 ]
                    },

        "F466N"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  213,  138, 132 ]
                    },

        "F470N"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  211,  132, 135 ]
                    },

        "F480M"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  212,  152, 151 ]
                    },

    ////////////////////////////////////////////////////////////////////////////
    // JWST MIRI Filters  - Palette Settings
    ////////////////////////////////////////////////////////////////////////////

        "F560W"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  145,   98, 168 ]
                    },

        "F770W"   : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  121,  104, 196]
                    },

        "F1000W"  : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  129,  146, 218 ]
                    },

        "F1130W"  : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  142,  171, 213 ]
                    },

        "F1280W"  : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  155,  190, 196 ]
                    },

        "F1500W"  : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  175,  203, 165 ]
                    },

        "F1800W"  : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  203,  209, 135 ]
                    },

        "F2100W"  : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  222,  189, 120 ]
                    },

        "F2550W"  : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  204,  107, 100 ]
                    },

        "F2550WR" : {
                        "NONE"    : [ 100,  255,  255, 255 ],
                        "HST"     : [ 100,  255,  255, 255 ],
                        "CFHT"    : [ 100,  255,  255, 255 ],
                        "SDSS"    : [ 100,  255,  255, 255 ],
                        "NATURAL" : [ 100,  255,    0,   0 ],
                        "JWST"    : [ 100,  204,  107, 100 ]
                    }
    }
}

//------------------------------------------------------------------------------

Palettes.prototype = new Object;

//------------------------------------------------------------------------------

#endif   // DC_CombineImages_default_system_palettes_js

///////////////////////////////////////////////////////////////////////////////
// EOF DC_CombineImages_default_system_palettes.js
///////////////////////////////////////////////////////////////////////////////




